# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoiceRateExtended(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoiceRateExtended - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'currency': 'str',
            'amendment_id': 'str',
            'type': 'str',
            'effective_date': 'datetime',
            'group_name': 'str',
            'area_code': 'str',
            'deletion_marker': 'bool',
            'outbound_rate': 'float',
            'outbound_duration_minimum_seconds': 'int',
            'outbound_duration_increment_seconds': 'int',
            'inbound_tolled_rate': 'float',
            'inbound_tolled_duration_minimum_seconds': 'int',
            'inbound_tolled_duration_increment_seconds': 'int',
            'inbound_toll_free_rate': 'float',
            'inbound_toll_free_duration_minimum_seconds': 'int',
            'inbound_toll_free_duration_increment_seconds': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'currency': 'currency',
            'amendment_id': 'amendmentId',
            'type': 'type',
            'effective_date': 'effectiveDate',
            'group_name': 'groupName',
            'area_code': 'areaCode',
            'deletion_marker': 'deletionMarker',
            'outbound_rate': 'outboundRate',
            'outbound_duration_minimum_seconds': 'outboundDurationMinimumSeconds',
            'outbound_duration_increment_seconds': 'outboundDurationIncrementSeconds',
            'inbound_tolled_rate': 'inboundTolledRate',
            'inbound_tolled_duration_minimum_seconds': 'inboundTolledDurationMinimumSeconds',
            'inbound_tolled_duration_increment_seconds': 'inboundTolledDurationIncrementSeconds',
            'inbound_toll_free_rate': 'inboundTollFreeRate',
            'inbound_toll_free_duration_minimum_seconds': 'inboundTollFreeDurationMinimumSeconds',
            'inbound_toll_free_duration_increment_seconds': 'inboundTollFreeDurationIncrementSeconds',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._currency = None
        self._amendment_id = None
        self._type = None
        self._effective_date = None
        self._group_name = None
        self._area_code = None
        self._deletion_marker = False
        self._outbound_rate = None
        self._outbound_duration_minimum_seconds = None
        self._outbound_duration_increment_seconds = None
        self._inbound_tolled_rate = None
        self._inbound_tolled_duration_minimum_seconds = None
        self._inbound_tolled_duration_increment_seconds = None
        self._inbound_toll_free_rate = None
        self._inbound_toll_free_duration_minimum_seconds = None
        self._inbound_toll_free_duration_increment_seconds = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this VoiceRateExtended.
        The globally unique identifier for the object.

        :return: The id of this VoiceRateExtended.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoiceRateExtended.
        The globally unique identifier for the object.

        :param id: The id of this VoiceRateExtended.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VoiceRateExtended.


        :return: The name of this VoiceRateExtended.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VoiceRateExtended.


        :param name: The name of this VoiceRateExtended.
        :type: str
        """
        self._name = name

    @property
    def currency(self):
        """
        Gets the currency of this VoiceRateExtended.
        The ISO 4217 currency code of the voice rate.

        :return: The currency of this VoiceRateExtended.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this VoiceRateExtended.
        The ISO 4217 currency code of the voice rate.

        :param currency: The currency of this VoiceRateExtended.
        :type: str
        """
        self._currency = currency

    @property
    def amendment_id(self):
        """
        Gets the amendment_id of this VoiceRateExtended.
        The amendment Id of the voice rate.

        :return: The amendment_id of this VoiceRateExtended.
        :rtype: str
        """
        return self._amendment_id

    @amendment_id.setter
    def amendment_id(self, amendment_id):
        """
        Sets the amendment_id of this VoiceRateExtended.
        The amendment Id of the voice rate.

        :param amendment_id: The amendment_id of this VoiceRateExtended.
        :type: str
        """
        self._amendment_id = amendment_id

    @property
    def type(self):
        """
        Gets the type of this VoiceRateExtended.
        The voice rate type.

        :return: The type of this VoiceRateExtended.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VoiceRateExtended.
        The voice rate type.

        :param type: The type of this VoiceRateExtended.
        :type: str
        """
        allowed_values = ["RATE_TOLL_FREE", "RATE_TOLLED", "OUTBOUND_INTERSTATE", "OUTBOUND_INTRASTATE", "OUTBOUND_LOCAL", "EXTENDED"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def effective_date(self):
        """
        Gets the effective_date of this VoiceRateExtended.
        The effective date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_date of this VoiceRateExtended.
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this VoiceRateExtended.
        The effective date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_date: The effective_date of this VoiceRateExtended.
        :type: datetime
        """
        self._effective_date = effective_date

    @property
    def group_name(self):
        """
        Gets the group_name of this VoiceRateExtended.
        The group containing this area code.

        :return: The group_name of this VoiceRateExtended.
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """
        Sets the group_name of this VoiceRateExtended.
        The group containing this area code.

        :param group_name: The group_name of this VoiceRateExtended.
        :type: str
        """
        self._group_name = group_name

    @property
    def area_code(self):
        """
        Gets the area_code of this VoiceRateExtended.
        The area code.

        :return: The area_code of this VoiceRateExtended.
        :rtype: str
        """
        return self._area_code

    @area_code.setter
    def area_code(self, area_code):
        """
        Sets the area_code of this VoiceRateExtended.
        The area code.

        :param area_code: The area_code of this VoiceRateExtended.
        :type: str
        """
        self._area_code = area_code

    @property
    def deletion_marker(self):
        """
        Gets the deletion_marker of this VoiceRateExtended.
        The deletion marker.

        :return: The deletion_marker of this VoiceRateExtended.
        :rtype: bool
        """
        return self._deletion_marker

    @deletion_marker.setter
    def deletion_marker(self, deletion_marker):
        """
        Sets the deletion_marker of this VoiceRateExtended.
        The deletion marker.

        :param deletion_marker: The deletion_marker of this VoiceRateExtended.
        :type: bool
        """
        self._deletion_marker = deletion_marker

    @property
    def outbound_rate(self):
        """
        Gets the outbound_rate of this VoiceRateExtended.
        The outbound extended rate.

        :return: The outbound_rate of this VoiceRateExtended.
        :rtype: float
        """
        return self._outbound_rate

    @outbound_rate.setter
    def outbound_rate(self, outbound_rate):
        """
        Sets the outbound_rate of this VoiceRateExtended.
        The outbound extended rate.

        :param outbound_rate: The outbound_rate of this VoiceRateExtended.
        :type: float
        """
        self._outbound_rate = outbound_rate

    @property
    def outbound_duration_minimum_seconds(self):
        """
        Gets the outbound_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :return: The outbound_duration_minimum_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._outbound_duration_minimum_seconds

    @outbound_duration_minimum_seconds.setter
    def outbound_duration_minimum_seconds(self, outbound_duration_minimum_seconds):
        """
        Sets the outbound_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :param outbound_duration_minimum_seconds: The outbound_duration_minimum_seconds of this VoiceRateExtended.
        :type: int
        """
        self._outbound_duration_minimum_seconds = outbound_duration_minimum_seconds

    @property
    def outbound_duration_increment_seconds(self):
        """
        Gets the outbound_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :return: The outbound_duration_increment_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._outbound_duration_increment_seconds

    @outbound_duration_increment_seconds.setter
    def outbound_duration_increment_seconds(self, outbound_duration_increment_seconds):
        """
        Sets the outbound_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :param outbound_duration_increment_seconds: The outbound_duration_increment_seconds of this VoiceRateExtended.
        :type: int
        """
        self._outbound_duration_increment_seconds = outbound_duration_increment_seconds

    @property
    def inbound_tolled_rate(self):
        """
        Gets the inbound_tolled_rate of this VoiceRateExtended.
        The inbound tolled rate.

        :return: The inbound_tolled_rate of this VoiceRateExtended.
        :rtype: float
        """
        return self._inbound_tolled_rate

    @inbound_tolled_rate.setter
    def inbound_tolled_rate(self, inbound_tolled_rate):
        """
        Sets the inbound_tolled_rate of this VoiceRateExtended.
        The inbound tolled rate.

        :param inbound_tolled_rate: The inbound_tolled_rate of this VoiceRateExtended.
        :type: float
        """
        self._inbound_tolled_rate = inbound_tolled_rate

    @property
    def inbound_tolled_duration_minimum_seconds(self):
        """
        Gets the inbound_tolled_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :return: The inbound_tolled_duration_minimum_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._inbound_tolled_duration_minimum_seconds

    @inbound_tolled_duration_minimum_seconds.setter
    def inbound_tolled_duration_minimum_seconds(self, inbound_tolled_duration_minimum_seconds):
        """
        Sets the inbound_tolled_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :param inbound_tolled_duration_minimum_seconds: The inbound_tolled_duration_minimum_seconds of this VoiceRateExtended.
        :type: int
        """
        self._inbound_tolled_duration_minimum_seconds = inbound_tolled_duration_minimum_seconds

    @property
    def inbound_tolled_duration_increment_seconds(self):
        """
        Gets the inbound_tolled_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :return: The inbound_tolled_duration_increment_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._inbound_tolled_duration_increment_seconds

    @inbound_tolled_duration_increment_seconds.setter
    def inbound_tolled_duration_increment_seconds(self, inbound_tolled_duration_increment_seconds):
        """
        Sets the inbound_tolled_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :param inbound_tolled_duration_increment_seconds: The inbound_tolled_duration_increment_seconds of this VoiceRateExtended.
        :type: int
        """
        self._inbound_tolled_duration_increment_seconds = inbound_tolled_duration_increment_seconds

    @property
    def inbound_toll_free_rate(self):
        """
        Gets the inbound_toll_free_rate of this VoiceRateExtended.
        The inbound toll-free rate.

        :return: The inbound_toll_free_rate of this VoiceRateExtended.
        :rtype: float
        """
        return self._inbound_toll_free_rate

    @inbound_toll_free_rate.setter
    def inbound_toll_free_rate(self, inbound_toll_free_rate):
        """
        Sets the inbound_toll_free_rate of this VoiceRateExtended.
        The inbound toll-free rate.

        :param inbound_toll_free_rate: The inbound_toll_free_rate of this VoiceRateExtended.
        :type: float
        """
        self._inbound_toll_free_rate = inbound_toll_free_rate

    @property
    def inbound_toll_free_duration_minimum_seconds(self):
        """
        Gets the inbound_toll_free_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :return: The inbound_toll_free_duration_minimum_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._inbound_toll_free_duration_minimum_seconds

    @inbound_toll_free_duration_minimum_seconds.setter
    def inbound_toll_free_duration_minimum_seconds(self, inbound_toll_free_duration_minimum_seconds):
        """
        Sets the inbound_toll_free_duration_minimum_seconds of this VoiceRateExtended.
        The minimum duration charged in seconds.

        :param inbound_toll_free_duration_minimum_seconds: The inbound_toll_free_duration_minimum_seconds of this VoiceRateExtended.
        :type: int
        """
        self._inbound_toll_free_duration_minimum_seconds = inbound_toll_free_duration_minimum_seconds

    @property
    def inbound_toll_free_duration_increment_seconds(self):
        """
        Gets the inbound_toll_free_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :return: The inbound_toll_free_duration_increment_seconds of this VoiceRateExtended.
        :rtype: int
        """
        return self._inbound_toll_free_duration_increment_seconds

    @inbound_toll_free_duration_increment_seconds.setter
    def inbound_toll_free_duration_increment_seconds(self, inbound_toll_free_duration_increment_seconds):
        """
        Sets the inbound_toll_free_duration_increment_seconds of this VoiceRateExtended.
        The billing duration increment in seconds.

        :param inbound_toll_free_duration_increment_seconds: The inbound_toll_free_duration_increment_seconds of this VoiceRateExtended.
        :type: int
        """
        self._inbound_toll_free_duration_increment_seconds = inbound_toll_free_duration_increment_seconds

    @property
    def self_uri(self):
        """
        Gets the self_uri of this VoiceRateExtended.
        The URI for this object

        :return: The self_uri of this VoiceRateExtended.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this VoiceRateExtended.
        The URI for this object

        :param self_uri: The self_uri of this VoiceRateExtended.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AggregationQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AggregationQuery - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'interval': 'str',
            'granularity': 'datetime',
            'group_by': 'list[str]',
            'filter': 'AnalyticsQueryFilter',
            'metrics': 'list[str]',
            'flatten_multivalued_dimensions': 'bool'
        }

        self.attribute_map = {
            'interval': 'interval',
            'granularity': 'granularity',
            'group_by': 'groupBy',
            'filter': 'filter',
            'metrics': 'metrics',
            'flatten_multivalued_dimensions': 'flattenMultivaluedDimensions'
        }

        self._interval = None
        self._granularity = None
        self._group_by = None
        self._filter = None
        self._metrics = None
        self._flatten_multivalued_dimensions = False

    @property
    def interval(self):
        """
        Gets the interval of this AggregationQuery.
        Behaves like one clause in a SQL WHERE. Specifies the date and time range of data being queried. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this AggregationQuery.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this AggregationQuery.
        Behaves like one clause in a SQL WHERE. Specifies the date and time range of data being queried. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this AggregationQuery.
        :type: str
        """
        self._interval = interval

    @property
    def granularity(self):
        """
        Gets the granularity of this AggregationQuery.
        Granularity aggregates metrics into subpartitions within the time interval specified. The default granularity is the same duration as the interval. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :return: The granularity of this AggregationQuery.
        :rtype: datetime
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this AggregationQuery.
        Granularity aggregates metrics into subpartitions within the time interval specified. The default granularity is the same duration as the interval. Periods are represented as an ISO-8601 string. For example: P1D or P1DT12H

        :param granularity: The granularity of this AggregationQuery.
        :type: datetime
        """
        self._granularity = granularity

    @property
    def group_by(self):
        """
        Gets the group_by of this AggregationQuery.
        Behaves like a SQL GROUPBY. Allows for multiple levels of grouping as a list of dimensions. Partitions resulting aggregate computations into distinct named subgroups rather than across the entire result set as if it were one group.

        :return: The group_by of this AggregationQuery.
        :rtype: list[str]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this AggregationQuery.
        Behaves like a SQL GROUPBY. Allows for multiple levels of grouping as a list of dimensions. Partitions resulting aggregate computations into distinct named subgroups rather than across the entire result set as if it were one group.

        :param group_by: The group_by of this AggregationQuery.
        :type: list[str]
        """
        self._group_by = group_by

    @property
    def filter(self):
        """
        Gets the filter of this AggregationQuery.
        Behaves like a SQL WHERE clause. This is ANDed with the interval parameter. Expresses boolean logical predicates as well as dimensional filters

        :return: The filter of this AggregationQuery.
        :rtype: AnalyticsQueryFilter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this AggregationQuery.
        Behaves like a SQL WHERE clause. This is ANDed with the interval parameter. Expresses boolean logical predicates as well as dimensional filters

        :param filter: The filter of this AggregationQuery.
        :type: AnalyticsQueryFilter
        """
        self._filter = filter

    @property
    def metrics(self):
        """
        Gets the metrics of this AggregationQuery.
        Behaves like a SQL SELECT clause. Enables retrieving only named metrics. If omitted, all metrics that are available will be returned (like SELECT *).

        :return: The metrics of this AggregationQuery.
        :rtype: list[str]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this AggregationQuery.
        Behaves like a SQL SELECT clause. Enables retrieving only named metrics. If omitted, all metrics that are available will be returned (like SELECT *).

        :param metrics: The metrics of this AggregationQuery.
        :type: list[str]
        """
        self._metrics = metrics

    @property
    def flatten_multivalued_dimensions(self):
        """
        Gets the flatten_multivalued_dimensions of this AggregationQuery.
        Flattens any multivalued dimensions used in response groups (e.g. ['a','b','c']->'a,b,c')

        :return: The flatten_multivalued_dimensions of this AggregationQuery.
        :rtype: bool
        """
        return self._flatten_multivalued_dimensions

    @flatten_multivalued_dimensions.setter
    def flatten_multivalued_dimensions(self, flatten_multivalued_dimensions):
        """
        Sets the flatten_multivalued_dimensions of this AggregationQuery.
        Flattens any multivalued dimensions used in response groups (e.g. ['a','b','c']->'a,b,c')

        :param flatten_multivalued_dimensions: The flatten_multivalued_dimensions of this AggregationQuery.
        :type: bool
        """
        self._flatten_multivalued_dimensions = flatten_multivalued_dimensions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VideoMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VideoMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'UriReference',
            'queue': 'UriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ErrorBody',
            'script': 'UriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'audio_muted': 'bool',
            'video_muted': 'bool',
            'sharing_screen': 'bool',
            'peer_count': 'int',
            'context': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'audio_muted': 'audioMuted',
            'video_muted': 'videoMuted',
            'sharing_screen': 'sharingScreen',
            'peer_count': 'peerCount',
            'context': 'context'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = False
        self._wrapup_required = False
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = False
        self._audio_muted = False
        self._video_muted = False
        self._sharing_screen = False
        self._peer_count = None
        self._context = None

    @property
    def id(self):
        """
        Gets the id of this VideoMediaParticipant.
        The unique participant ID.

        :return: The id of this VideoMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VideoMediaParticipant.
        The unique participant ID.

        :param id: The id of this VideoMediaParticipant.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VideoMediaParticipant.
        The display friendly name of the participant.

        :return: The name of this VideoMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VideoMediaParticipant.
        The display friendly name of the participant.

        :param name: The name of this VideoMediaParticipant.
        :type: str
        """
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this VideoMediaParticipant.
        The participant address.

        :return: The address of this VideoMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this VideoMediaParticipant.
        The participant address.

        :param address: The address of this VideoMediaParticipant.
        :type: str
        """
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this VideoMediaParticipant.
        The time when this participant joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_time of this VideoMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this VideoMediaParticipant.
        The time when this participant joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_time: The start_time of this VideoMediaParticipant.
        :type: datetime
        """
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this VideoMediaParticipant.
        The time when this participant went connected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this VideoMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this VideoMediaParticipant.
        The time when this participant went connected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this VideoMediaParticipant.
        :type: datetime
        """
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this VideoMediaParticipant.
        The time when this participant when disconnected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_time of this VideoMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this VideoMediaParticipant.
        The time when this participant when disconnected on the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_time: The end_time of this VideoMediaParticipant.
        :type: datetime
        """
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this VideoMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_hold_time of this VideoMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this VideoMediaParticipant.
        The time when this participant's hold started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_hold_time: The start_hold_time of this VideoMediaParticipant.
        :type: datetime
        """
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this VideoMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :return: The purpose of this VideoMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this VideoMediaParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :param purpose: The purpose of this VideoMediaParticipant.
        :type: str
        """
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this VideoMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :return: The state of this VideoMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this VideoMediaParticipant.
        The participant's state.  Values can be: 'alerting', 'connected', 'disconnected', 'dialing', 'contacting

        :param state: The state of this VideoMediaParticipant.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "CONVERTING", "UPLOADING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this VideoMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :return: The direction of this VideoMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this VideoMediaParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :param direction: The direction of this VideoMediaParticipant.
        :type: str
        """
        allowed_values = ["INBOUND", "OUTBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )
        self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this VideoMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :return: The disconnect_type of this VideoMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this VideoMediaParticipant.
        The reason the participant was disconnected from the conversation.

        :param disconnect_type: The disconnect_type of this VideoMediaParticipant.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this VideoMediaParticipant.
        Value is true when the participant is on hold.

        :return: The held of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this VideoMediaParticipant.
        Value is true when the participant is on hold.

        :param held: The held of this VideoMediaParticipant.
        :type: bool
        """
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this VideoMediaParticipant.
        Value is true when the participant requires wrap-up.

        :return: The wrapup_required of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this VideoMediaParticipant.
        Value is true when the participant requires wrap-up.

        :param wrapup_required: The wrapup_required of this VideoMediaParticipant.
        :type: bool
        """
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this VideoMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :return: The wrapup_prompt of this VideoMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this VideoMediaParticipant.
        The wrap-up prompt indicating the type of wrap-up to be performed.

        :param wrapup_prompt: The wrapup_prompt of this VideoMediaParticipant.
        :type: str
        """
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this VideoMediaParticipant.
        The PureCloud user for this participant.

        :return: The user of this VideoMediaParticipant.
        :rtype: UriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this VideoMediaParticipant.
        The PureCloud user for this participant.

        :param user: The user of this VideoMediaParticipant.
        :type: UriReference
        """
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this VideoMediaParticipant.
        The PureCloud queue for this participant.

        :return: The queue of this VideoMediaParticipant.
        :rtype: UriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this VideoMediaParticipant.
        The PureCloud queue for this participant.

        :param queue: The queue of this VideoMediaParticipant.
        :type: UriReference
        """
        self._queue = queue

    @property
    def attributes(self):
        """
        Gets the attributes of this VideoMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :return: The attributes of this VideoMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this VideoMediaParticipant.
        A list of ad-hoc attributes for the participant.

        :param attributes: The attributes of this VideoMediaParticipant.
        :type: dict(str, str)
        """
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this VideoMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :return: The error_info of this VideoMediaParticipant.
        :rtype: ErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this VideoMediaParticipant.
        If the conversation ends in error, contains additional error details.

        :param error_info: The error_info of this VideoMediaParticipant.
        :type: ErrorBody
        """
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this VideoMediaParticipant.
        The Engage script that should be used by this participant.

        :return: The script of this VideoMediaParticipant.
        :rtype: UriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this VideoMediaParticipant.
        The Engage script that should be used by this participant.

        :param script: The script of this VideoMediaParticipant.
        :type: UriReference
        """
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this VideoMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :return: The wrapup_timeout_ms of this VideoMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this VideoMediaParticipant.
        The amount of time the participant has to complete wrap-up.

        :param wrapup_timeout_ms: The wrapup_timeout_ms of this VideoMediaParticipant.
        :type: int
        """
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this VideoMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :return: The wrapup_skipped of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this VideoMediaParticipant.
        Value is true when the participant has skipped wrap-up.

        :param wrapup_skipped: The wrapup_skipped of this VideoMediaParticipant.
        :type: bool
        """
        self._wrapup_skipped = wrapup_skipped

    @property
    def audio_muted(self):
        """
        Gets the audio_muted of this VideoMediaParticipant.
        Value is true when audio is muted.

        :return: The audio_muted of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._audio_muted

    @audio_muted.setter
    def audio_muted(self, audio_muted):
        """
        Sets the audio_muted of this VideoMediaParticipant.
        Value is true when audio is muted.

        :param audio_muted: The audio_muted of this VideoMediaParticipant.
        :type: bool
        """
        self._audio_muted = audio_muted

    @property
    def video_muted(self):
        """
        Gets the video_muted of this VideoMediaParticipant.
        Value is true when video is muted.

        :return: The video_muted of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._video_muted

    @video_muted.setter
    def video_muted(self, video_muted):
        """
        Sets the video_muted of this VideoMediaParticipant.
        Value is true when video is muted.

        :param video_muted: The video_muted of this VideoMediaParticipant.
        :type: bool
        """
        self._video_muted = video_muted

    @property
    def sharing_screen(self):
        """
        Gets the sharing_screen of this VideoMediaParticipant.
        Value is true when screen sharing is enabled.

        :return: The sharing_screen of this VideoMediaParticipant.
        :rtype: bool
        """
        return self._sharing_screen

    @sharing_screen.setter
    def sharing_screen(self, sharing_screen):
        """
        Sets the sharing_screen of this VideoMediaParticipant.
        Value is true when screen sharing is enabled.

        :param sharing_screen: The sharing_screen of this VideoMediaParticipant.
        :type: bool
        """
        self._sharing_screen = sharing_screen

    @property
    def peer_count(self):
        """
        Gets the peer_count of this VideoMediaParticipant.
        The number of peers of this participant.

        :return: The peer_count of this VideoMediaParticipant.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this VideoMediaParticipant.
        The number of peers of this participant.

        :param peer_count: The peer_count of this VideoMediaParticipant.
        :type: int
        """
        self._peer_count = peer_count

    @property
    def context(self):
        """
        Gets the context of this VideoMediaParticipant.
        The context for this participant.

        :return: The context of this VideoMediaParticipant.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this VideoMediaParticipant.
        The context for this participant.

        :param context: The context of this VideoMediaParticipant.
        :type: str
        """
        self._context = context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ContactAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContactAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'address1': 'str',
            'address2': 'str',
            'city': 'str',
            'state': 'str',
            'postal_code': 'str',
            'country_code': 'str'
        }

        self.attribute_map = {
            'address1': 'address1',
            'address2': 'address2',
            'city': 'city',
            'state': 'state',
            'postal_code': 'postalCode',
            'country_code': 'countryCode'
        }

        self._address1 = None
        self._address2 = None
        self._city = None
        self._state = None
        self._postal_code = None
        self._country_code = None

    @property
    def address1(self):
        """
        Gets the address1 of this ContactAddress.


        :return: The address1 of this ContactAddress.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this ContactAddress.


        :param address1: The address1 of this ContactAddress.
        :type: str
        """
        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this ContactAddress.


        :return: The address2 of this ContactAddress.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this ContactAddress.


        :param address2: The address2 of this ContactAddress.
        :type: str
        """
        self._address2 = address2

    @property
    def city(self):
        """
        Gets the city of this ContactAddress.


        :return: The city of this ContactAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this ContactAddress.


        :param city: The city of this ContactAddress.
        :type: str
        """
        self._city = city

    @property
    def state(self):
        """
        Gets the state of this ContactAddress.


        :return: The state of this ContactAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ContactAddress.


        :param state: The state of this ContactAddress.
        :type: str
        """
        self._state = state

    @property
    def postal_code(self):
        """
        Gets the postal_code of this ContactAddress.


        :return: The postal_code of this ContactAddress.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this ContactAddress.


        :param postal_code: The postal_code of this ContactAddress.
        :type: str
        """
        self._postal_code = postal_code

    @property
    def country_code(self):
        """
        Gets the country_code of this ContactAddress.


        :return: The country_code of this ContactAddress.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this ContactAddress.


        :param country_code: The country_code of this ContactAddress.
        :type: str
        """
        self._country_code = country_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TwitterExpression(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TwitterExpression - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'is_dispositioned': 'bool',
            'is_noise': 'bool',
            'gistener': 'Gistener',
            'tweet_id': 'str',
            'text': 'str',
            'tweet_created': 'datetime',
            'is_reply': 'bool',
            'is_retweet': 'bool',
            'retweet_parent_id': 'str',
            'retweet_count': 'int',
            'is_quoted_tweet': 'bool',
            'quoted_parent_id': 'str',
            'user_id': 'str',
            'user_name': 'str',
            'user_screen_name': 'str',
            'user_tweet_count': 'int',
            'user_followers_count': 'int',
            'group_tags': 'list[GroupTag]',
            'routed': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'is_dispositioned': 'isDispositioned',
            'is_noise': 'isNoise',
            'gistener': 'gistener',
            'tweet_id': 'tweetId',
            'text': 'text',
            'tweet_created': 'tweetCreated',
            'is_reply': 'isReply',
            'is_retweet': 'isRetweet',
            'retweet_parent_id': 'retweetParentId',
            'retweet_count': 'retweetCount',
            'is_quoted_tweet': 'isQuotedTweet',
            'quoted_parent_id': 'quotedParentId',
            'user_id': 'userId',
            'user_name': 'userName',
            'user_screen_name': 'userScreenName',
            'user_tweet_count': 'userTweetCount',
            'user_followers_count': 'userFollowersCount',
            'group_tags': 'groupTags',
            'routed': 'routed',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._is_dispositioned = False
        self._is_noise = False
        self._gistener = None
        self._tweet_id = None
        self._text = None
        self._tweet_created = None
        self._is_reply = False
        self._is_retweet = False
        self._retweet_parent_id = None
        self._retweet_count = None
        self._is_quoted_tweet = False
        self._quoted_parent_id = None
        self._user_id = None
        self._user_name = None
        self._user_screen_name = None
        self._user_tweet_count = None
        self._user_followers_count = None
        self._group_tags = None
        self._routed = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TwitterExpression.
        The globally unique identifier for the object.

        :return: The id of this TwitterExpression.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TwitterExpression.
        The globally unique identifier for the object.

        :param id: The id of this TwitterExpression.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TwitterExpression.


        :return: The name of this TwitterExpression.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TwitterExpression.


        :param name: The name of this TwitterExpression.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this TwitterExpression.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this TwitterExpression.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this TwitterExpression.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this TwitterExpression.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this TwitterExpression.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this TwitterExpression.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this TwitterExpression.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this TwitterExpression.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def is_dispositioned(self):
        """
        Gets the is_dispositioned of this TwitterExpression.
        True once the expression has been dispositioned by an agent through the ACD process

        :return: The is_dispositioned of this TwitterExpression.
        :rtype: bool
        """
        return self._is_dispositioned

    @is_dispositioned.setter
    def is_dispositioned(self, is_dispositioned):
        """
        Sets the is_dispositioned of this TwitterExpression.
        True once the expression has been dispositioned by an agent through the ACD process

        :param is_dispositioned: The is_dispositioned of this TwitterExpression.
        :type: bool
        """
        self._is_dispositioned = is_dispositioned

    @property
    def is_noise(self):
        """
        Gets the is_noise of this TwitterExpression.
        Indicates if a user/agent found this expression to be undesirable

        :return: The is_noise of this TwitterExpression.
        :rtype: bool
        """
        return self._is_noise

    @is_noise.setter
    def is_noise(self, is_noise):
        """
        Sets the is_noise of this TwitterExpression.
        Indicates if a user/agent found this expression to be undesirable

        :param is_noise: The is_noise of this TwitterExpression.
        :type: bool
        """
        self._is_noise = is_noise

    @property
    def gistener(self):
        """
        Gets the gistener of this TwitterExpression.
        The Gistener that generated this expression

        :return: The gistener of this TwitterExpression.
        :rtype: Gistener
        """
        return self._gistener

    @gistener.setter
    def gistener(self, gistener):
        """
        Sets the gistener of this TwitterExpression.
        The Gistener that generated this expression

        :param gistener: The gistener of this TwitterExpression.
        :type: Gistener
        """
        self._gistener = gistener

    @property
    def tweet_id(self):
        """
        Gets the tweet_id of this TwitterExpression.
        Twitter: the tweet's unique id

        :return: The tweet_id of this TwitterExpression.
        :rtype: str
        """
        return self._tweet_id

    @tweet_id.setter
    def tweet_id(self, tweet_id):
        """
        Sets the tweet_id of this TwitterExpression.
        Twitter: the tweet's unique id

        :param tweet_id: The tweet_id of this TwitterExpression.
        :type: str
        """
        self._tweet_id = tweet_id

    @property
    def text(self):
        """
        Gets the text of this TwitterExpression.
        Twitter: the tweets full text

        :return: The text of this TwitterExpression.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this TwitterExpression.
        Twitter: the tweets full text

        :param text: The text of this TwitterExpression.
        :type: str
        """
        self._text = text

    @property
    def tweet_created(self):
        """
        Gets the tweet_created of this TwitterExpression.
        Twitter: the date the tweet was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The tweet_created of this TwitterExpression.
        :rtype: datetime
        """
        return self._tweet_created

    @tweet_created.setter
    def tweet_created(self, tweet_created):
        """
        Sets the tweet_created of this TwitterExpression.
        Twitter: the date the tweet was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param tweet_created: The tweet_created of this TwitterExpression.
        :type: datetime
        """
        self._tweet_created = tweet_created

    @property
    def is_reply(self):
        """
        Gets the is_reply of this TwitterExpression.
        Twitter: indicates this tweet as a reply to another tweet

        :return: The is_reply of this TwitterExpression.
        :rtype: bool
        """
        return self._is_reply

    @is_reply.setter
    def is_reply(self, is_reply):
        """
        Sets the is_reply of this TwitterExpression.
        Twitter: indicates this tweet as a reply to another tweet

        :param is_reply: The is_reply of this TwitterExpression.
        :type: bool
        """
        self._is_reply = is_reply

    @property
    def is_retweet(self):
        """
        Gets the is_retweet of this TwitterExpression.
        Twitter: indicates this tweet as a 'retweet' of another tweet

        :return: The is_retweet of this TwitterExpression.
        :rtype: bool
        """
        return self._is_retweet

    @is_retweet.setter
    def is_retweet(self, is_retweet):
        """
        Sets the is_retweet of this TwitterExpression.
        Twitter: indicates this tweet as a 'retweet' of another tweet

        :param is_retweet: The is_retweet of this TwitterExpression.
        :type: bool
        """
        self._is_retweet = is_retweet

    @property
    def retweet_parent_id(self):
        """
        Gets the retweet_parent_id of this TwitterExpression.
        Twitter: when the expression is a retweet, this is Twitter's id of the original tweet

        :return: The retweet_parent_id of this TwitterExpression.
        :rtype: str
        """
        return self._retweet_parent_id

    @retweet_parent_id.setter
    def retweet_parent_id(self, retweet_parent_id):
        """
        Sets the retweet_parent_id of this TwitterExpression.
        Twitter: when the expression is a retweet, this is Twitter's id of the original tweet

        :param retweet_parent_id: The retweet_parent_id of this TwitterExpression.
        :type: str
        """
        self._retweet_parent_id = retweet_parent_id

    @property
    def retweet_count(self):
        """
        Gets the retweet_count of this TwitterExpression.
        Twitter: the number of times the parent tweet was retweeted - at the time this expression was created

        :return: The retweet_count of this TwitterExpression.
        :rtype: int
        """
        return self._retweet_count

    @retweet_count.setter
    def retweet_count(self, retweet_count):
        """
        Sets the retweet_count of this TwitterExpression.
        Twitter: the number of times the parent tweet was retweeted - at the time this expression was created

        :param retweet_count: The retweet_count of this TwitterExpression.
        :type: int
        """
        self._retweet_count = retweet_count

    @property
    def is_quoted_tweet(self):
        """
        Gets the is_quoted_tweet of this TwitterExpression.
        Twitter: indicates this expression as a quoted tweet (a tweet with an addendum as the primary text)

        :return: The is_quoted_tweet of this TwitterExpression.
        :rtype: bool
        """
        return self._is_quoted_tweet

    @is_quoted_tweet.setter
    def is_quoted_tweet(self, is_quoted_tweet):
        """
        Sets the is_quoted_tweet of this TwitterExpression.
        Twitter: indicates this expression as a quoted tweet (a tweet with an addendum as the primary text)

        :param is_quoted_tweet: The is_quoted_tweet of this TwitterExpression.
        :type: bool
        """
        self._is_quoted_tweet = is_quoted_tweet

    @property
    def quoted_parent_id(self):
        """
        Gets the quoted_parent_id of this TwitterExpression.
        Twitter: when the expression is a quoted tweet, this is Twitter's id of the original tweet (may not be immediately functional)

        :return: The quoted_parent_id of this TwitterExpression.
        :rtype: str
        """
        return self._quoted_parent_id

    @quoted_parent_id.setter
    def quoted_parent_id(self, quoted_parent_id):
        """
        Sets the quoted_parent_id of this TwitterExpression.
        Twitter: when the expression is a quoted tweet, this is Twitter's id of the original tweet (may not be immediately functional)

        :param quoted_parent_id: The quoted_parent_id of this TwitterExpression.
        :type: str
        """
        self._quoted_parent_id = quoted_parent_id

    @property
    def user_id(self):
        """
        Gets the user_id of this TwitterExpression.
        Twitter: the expressing user's Twitter id

        :return: The user_id of this TwitterExpression.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this TwitterExpression.
        Twitter: the expressing user's Twitter id

        :param user_id: The user_id of this TwitterExpression.
        :type: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        """
        Gets the user_name of this TwitterExpression.
        Twitter: the user's account name for the core service

        :return: The user_name of this TwitterExpression.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this TwitterExpression.
        Twitter: the user's account name for the core service

        :param user_name: The user_name of this TwitterExpression.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_screen_name(self):
        """
        Gets the user_screen_name of this TwitterExpression.
        Twitter: the user's custom 'branding' name (allowed to change over time)

        :return: The user_screen_name of this TwitterExpression.
        :rtype: str
        """
        return self._user_screen_name

    @user_screen_name.setter
    def user_screen_name(self, user_screen_name):
        """
        Sets the user_screen_name of this TwitterExpression.
        Twitter: the user's custom 'branding' name (allowed to change over time)

        :param user_screen_name: The user_screen_name of this TwitterExpression.
        :type: str
        """
        self._user_screen_name = user_screen_name

    @property
    def user_tweet_count(self):
        """
        Gets the user_tweet_count of this TwitterExpression.
        Twitter: the number of times this user has tweeted (includes all forms of expression replies/quotes/retweets)

        :return: The user_tweet_count of this TwitterExpression.
        :rtype: int
        """
        return self._user_tweet_count

    @user_tweet_count.setter
    def user_tweet_count(self, user_tweet_count):
        """
        Sets the user_tweet_count of this TwitterExpression.
        Twitter: the number of times this user has tweeted (includes all forms of expression replies/quotes/retweets)

        :param user_tweet_count: The user_tweet_count of this TwitterExpression.
        :type: int
        """
        self._user_tweet_count = user_tweet_count

    @property
    def user_followers_count(self):
        """
        Gets the user_followers_count of this TwitterExpression.
        Twitter: the number of followers this user has at the time of this expression

        :return: The user_followers_count of this TwitterExpression.
        :rtype: int
        """
        return self._user_followers_count

    @user_followers_count.setter
    def user_followers_count(self, user_followers_count):
        """
        Sets the user_followers_count of this TwitterExpression.
        Twitter: the number of followers this user has at the time of this expression

        :param user_followers_count: The user_followers_count of this TwitterExpression.
        :type: int
        """
        self._user_followers_count = user_followers_count

    @property
    def group_tags(self):
        """
        Gets the group_tags of this TwitterExpression.
        The Group Tags applied by the generating Gistener

        :return: The group_tags of this TwitterExpression.
        :rtype: list[GroupTag]
        """
        return self._group_tags

    @group_tags.setter
    def group_tags(self, group_tags):
        """
        Sets the group_tags of this TwitterExpression.
        The Group Tags applied by the generating Gistener

        :param group_tags: The group_tags of this TwitterExpression.
        :type: list[GroupTag]
        """
        self._group_tags = group_tags

    @property
    def routed(self):
        """
        Gets the routed of this TwitterExpression.


        :return: The routed of this TwitterExpression.
        :rtype: bool
        """
        return self._routed

    @routed.setter
    def routed(self, routed):
        """
        Sets the routed of this TwitterExpression.


        :param routed: The routed of this TwitterExpression.
        :type: bool
        """
        self._routed = routed

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TwitterExpression.
        The URI for this object

        :return: The self_uri of this TwitterExpression.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TwitterExpression.
        The URI for this object

        :param self_uri: The self_uri of this TwitterExpression.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into model package
from .account import Account
from .account_manager import AccountManager
from .account_overview import AccountOverview
from .account_status import AccountStatus
from .actions import Actions
from .acw_settings import AcwSettings
from .address import Address
from .address_listing import AddressListing
from .agent import Agent
from .agent_activity import AgentActivity
from .agent_activity_entity_listing import AgentActivityEntityListing
from .agent_evaluator_activity import AgentEvaluatorActivity
from .aggregate_data_container import AggregateDataContainer
from .aggregate_metric_data import AggregateMetricData
from .aggregate_query_response import AggregateQueryResponse
from .aggregation_query import AggregationQuery
from .aggregation_range import AggregationRange
from .aggregation_result import AggregationResult
from .aggregation_result_entry import AggregationResultEntry
from .analytics_conversation import AnalyticsConversation
from .analytics_conversation_query_response import AnalyticsConversationQueryResponse
from .analytics_conversation_segment import AnalyticsConversationSegment
from .analytics_evaluation import AnalyticsEvaluation
from .analytics_participant import AnalyticsParticipant
from .analytics_property import AnalyticsProperty
from .analytics_query_aggregation import AnalyticsQueryAggregation
from .analytics_query_clause import AnalyticsQueryClause
from .analytics_query_filter import AnalyticsQueryFilter
from .analytics_query_predicate import AnalyticsQueryPredicate
from .analytics_session import AnalyticsSession
from .annotation import Annotation
from .app import App
from .architect_audit_message import ArchitectAuditMessage
from .architect_audit_message_listing import ArchitectAuditMessageListing
from .archive_retention import ArchiveRetention
from .associated_document import AssociatedDocument
from .attachment import Attachment
from .attribute import Attribute
from .attribute_entity_listing import AttributeEntityListing
from .attribute_filter_item import AttributeFilterItem
from .attribute_query_request import AttributeQueryRequest
from .audit_change import AuditChange
from .audit_entity import AuditEntity
from .audit_entity_reference import AuditEntityReference
from .audit_facet import AuditFacet
from .audit_filter import AuditFilter
from .audit_message import AuditMessage
from .audit_search_result import AuditSearchResult
from .audit_user import AuditUser
from .available_additional_service import AvailableAdditionalService
from .available_additional_service_listing import AvailableAdditionalServiceListing
from .available_topic import AvailableTopic
from .available_topic_entity_listing import AvailableTopicEntityListing
from .backend_flow_available_actions import BackendFlowAvailableActions
from .basic_transform import BasicTransform
from .batch_command import BatchCommand
from .batch_item import BatchItem
from .batch_item_body import BatchItemBody
from .batch_reply import BatchReply
from .batch_reply_item import BatchReplyItem
from .billing_address import BillingAddress
from .billing_pending_task import BillingPendingTask
from .billing_period import BillingPeriod
from .billing_task_result import BillingTaskResult
from .bullseye import Bullseye
from .calibration import Calibration
from .calibration_assignment import CalibrationAssignment
from .calibration_entity_listing import CalibrationEntityListing
from .call import Call
from .call_command import CallCommand
from .call_conversation import CallConversation
from .call_conversation_entity_listing import CallConversationEntityListing
from .call_forwarding import CallForwarding
from .call_media_participant import CallMediaParticipant
from .call_media_policy import CallMediaPolicy
from .call_media_policy_conditions import CallMediaPolicyConditions
from .call_record import CallRecord
from .callable_contacts_diagnostic import CallableContactsDiagnostic
from .callable_time import CallableTime
from .callable_time_set import CallableTimeSet
from .callable_time_set_entity_listing import CallableTimeSetEntityListing
from .callback import Callback
from .callback_conversation import CallbackConversation
from .callback_conversation_entity_listing import CallbackConversationEntityListing
from .callback_media_participant import CallbackMediaParticipant
from .campaign import Campaign
from .campaign_diagnostics import CampaignDiagnostics
from .campaign_entity_listing import CampaignEntityListing
from .campaign_progress import CampaignProgress
from .campaign_schedule import CampaignSchedule
from .campaign_schedule_intervals import CampaignScheduleIntervals
from .campaign_sequence import CampaignSequence
from .campaign_sequence_entity_listing import CampaignSequenceEntityListing
from .campaign_stats import CampaignStats
from .campaign_time_slot import CampaignTimeSlot
from .carrier import Carrier
from .carrier_address import CarrierAddress
from .carrier_entity_listing import CarrierEntityListing
from .certificate import Certificate
from .certificate_authority_entity_listing import CertificateAuthorityEntityListing
from .certificate_details import CertificateDetails
from .change import Change
from .channel import Channel
from .channel_entity_listing import ChannelEntityListing
from .channel_topic import ChannelTopic
from .channel_topic_entity_listing import ChannelTopicEntityListing
from .charge import Charge
from .chat import Chat
from .chat_conversation import ChatConversation
from .chat_conversation_entity_listing import ChatConversationEntityListing
from .chat_media_participant import ChatMediaParticipant
from .chat_media_policy import ChatMediaPolicy
from .chat_media_policy_conditions import ChatMediaPolicyConditions
from .chat_message import ChatMessage
from .chat_message_user import ChatMessageUser
from .client_spreadsheet_transform import ClientSpreadsheetTransform
from .client_text_table_transform import ClientTextTableTransform
from .column_collapse import ColumnCollapse
from .command_status import CommandStatus
from .command_status_entity_listing import CommandStatusEntityListing
from .composer_template import ComposerTemplate
from .condition import Condition
from .connect_rate import ConnectRate
from .consult_transfer import ConsultTransfer
from .consult_transfer_response import ConsultTransferResponse
from .consult_transfer_update import ConsultTransferUpdate
from .consumed_resources_entity_listing import ConsumedResourcesEntityListing
from .consuming_resources_entity_listing import ConsumingResourcesEntityListing
from .contact import Contact
from .contact_address import ContactAddress
from .contact_callback_request import ContactCallbackRequest
from .contact_list import ContactList
from .contact_list_entity_listing import ContactListEntityListing
from .contact_listing import ContactListing
from .contact_phone_number_column import ContactPhoneNumberColumn
from .contact_sales import ContactSales
from .contact_sales_response import ContactSalesResponse
from .contact_sort import ContactSort
from .content_attribute_filter_item import ContentAttributeFilterItem
from .content_facet_filter_item import ContentFacetFilterItem
from .content_filter_item import ContentFilterItem
from .content_query_request import ContentQueryRequest
from .content_sort_item import ContentSortItem
from .contract import Contract
from .contract_job import ContractJob
from .control import Control
from .control_options import ControlOptions
from .conversation import Conversation
from .conversation_chat import ConversationChat
from .conversation_entity_listing import ConversationEntityListing
from .conversation_query import ConversationQuery
from .cover_sheet import CoverSheet
from .create_call_request import CreateCallRequest
from .create_call_response import CreateCallResponse
from .create_callback_command import CreateCallbackCommand
from .create_share_request import CreateShareRequest
from .create_share_request_member import CreateShareRequestMember
from .create_share_response import CreateShareResponse
from .create_template_from_script_request_data import CreateTemplateFromScriptRequestData
from .create_user import CreateUser
from .csv_schema import CsvSchema
from .currency import Currency
from .customer_account import CustomerAccount
from .did import DID
from .did_entity_listing import DIDEntityListing
from .did_pool import DIDPool
from .did_pool_entity_listing import DIDPoolEntityListing
from .data_item import DataItem
from .data_value_info import DataValueInfo
from .default_greeting_list import DefaultGreetingList
from .delete_retention import DeleteRetention
from .deleted_resource_consumer_entity_listing import DeletedResourceConsumerEntityListing
from .delta_document import DeltaDocument
from .delta_request import DeltaRequest
from .delta_response import DeltaResponse
from .dependency import Dependency
from .dependency_object import DependencyObject
from .dependency_object_entity_listing import DependencyObjectEntityListing
from .dependency_status import DependencyStatus
from .dependency_type import DependencyType
from .dependency_type_entity_listing import DependencyTypeEntityListing
from .destination import Destination
from .detail import Detail
from .diagnostic_email import DiagnosticEmail
from .dialer_action import DialerAction
from .dialer_audit_request import DialerAuditRequest
from .dialer_contact import DialerContact
from .dialer_preview import DialerPreview
from .dialer_rule import DialerRule
from .digit_length import DigitLength
from .disconnect_reason import DisconnectReason
from .discount import Discount
from .dnc_list import DncList
from .dnc_list_entity_listing import DncListEntityListing
from .dns import Dns
from .document import Document
from .document_attribute import DocumentAttribute
from .document_audit import DocumentAudit
from .document_audit_entity_listing import DocumentAuditEntityListing
from .document_entity_listing import DocumentEntityListing
from .document_thumbnail import DocumentThumbnail
from .document_update import DocumentUpdate
from .document_upload import DocumentUpload
from .domain_billing_period_entity_listing import DomainBillingPeriodEntityListing
from .domain_capabilities import DomainCapabilities
from .domain_certificate_authority import DomainCertificateAuthority
from .domain_edge_software_update_dto import DomainEdgeSoftwareUpdateDto
from .domain_edge_software_version_dto import DomainEdgeSoftwareVersionDto
from .domain_entity import DomainEntity
from .domain_entity_listing import DomainEntityListing
from .domain_entity_listing_evaluation_form import DomainEntityListingEvaluationForm
from .domain_entity_listing_query_result import DomainEntityListingQueryResult
from .domain_invoice_entity_listing import DomainInvoiceEntityListing
from .domain_logical_interface import DomainLogicalInterface
from .domain_network_address import DomainNetworkAddress
from .domain_network_command_response import DomainNetworkCommandResponse
from .domain_network_route import DomainNetworkRoute
from .domain_org_role_difference import DomainOrgRoleDifference
from .domain_organization_product import DomainOrganizationProduct
from .domain_organization_role import DomainOrganizationRole
from .domain_permission import DomainPermission
from .domain_permission_collection import DomainPermissionCollection
from .domain_permission_policy import DomainPermissionPolicy
from .domain_physical_capabilities import DomainPhysicalCapabilities
from .domain_physical_interface import DomainPhysicalInterface
from .domain_resource_condition_node import DomainResourceConditionNode
from .domain_resource_condition_value import DomainResourceConditionValue
from .domain_role import DomainRole
from .domain_schema_reference import DomainSchemaReference
from .domain_third_party_account_entity_listing import DomainThirdPartyAccountEntityListing
from .domain_third_party_subscription_entity_listing import DomainThirdPartySubscriptionEntityListing
from .domain_voice_rate_extended_response_item_entity_listing import DomainVoiceRateExtendedResponseItemEntityListing
from .domain_voice_rate_international_response_item_entity_listing import DomainVoiceRateInternationalResponseItemEntityListing
from .domain_voice_rate_response_item_entity_listing import DomainVoiceRateResponseItemEntityListing
from .download_response import DownloadResponse
from .duration_condition import DurationCondition
from .edge import Edge
from .edge_auto_update_config import EdgeAutoUpdateConfig
from .edge_entity_listing import EdgeEntityListing
from .edge_group import EdgeGroup
from .edge_group_entity_listing import EdgeGroupEntityListing
from .edge_interface import EdgeInterface
from .edge_line import EdgeLine
from .edge_line_entity_listing import EdgeLineEntityListing
from .edge_logs_job import EdgeLogsJob
from .edge_logs_job_file import EdgeLogsJobFile
from .edge_logs_job_request import EdgeLogsJobRequest
from .edge_logs_job_response import EdgeLogsJobResponse
from .edge_logs_job_upload_request import EdgeLogsJobUploadRequest
from .edge_version_information import EdgeVersionInformation
from .edge_version_report import EdgeVersionReport
from .email import Email
from .email_address import EmailAddress
from .email_attachment import EmailAttachment
from .email_conversation import EmailConversation
from .email_conversation_entity_listing import EmailConversationEntityListing
from .email_media_participant import EmailMediaParticipant
from .email_media_policy import EmailMediaPolicy
from .email_media_policy_conditions import EmailMediaPolicyConditions
from .email_message import EmailMessage
from .email_message_listing import EmailMessageListing
from .email_setup import EmailSetup
from .embedded_signature_view import EmbeddedSignatureView
from .encryption_key import EncryptionKey
from .encryption_key_entity_listing import EncryptionKeyEntityListing
from .endpoint import Endpoint
from .endpoint_entity_listing import EndpointEntityListing
from .entity import Entity
from .entry import Entry
from .error_body import ErrorBody
from .error_details import ErrorDetails
from .estimated_wait_time_predictions import EstimatedWaitTimePredictions
from .evaluation import Evaluation
from .evaluation_assignment import EvaluationAssignment
from .evaluation_entity_listing import EvaluationEntityListing
from .evaluation_form import EvaluationForm
from .evaluation_form_and_scoring_set import EvaluationFormAndScoringSet
from .evaluation_form_entity_listing import EvaluationFormEntityListing
from .evaluation_scoring_set import EvaluationScoringSet
from .evaluator_activity import EvaluatorActivity
from .evaluator_activity_entity_listing import EvaluatorActivityEntityListing
from .expansion_criterium import ExpansionCriterium
from .expression_response import ExpressionResponse
from .extension import Extension
from .extension_entity_listing import ExtensionEntityListing
from .extension_pool import ExtensionPool
from .extension_pool_entity_listing import ExtensionPoolEntityListing
from .external_contact import ExternalContact
from .external_organization import ExternalOrganization
from .external_organization_listing import ExternalOrganizationListing
from .facet_entry import FacetEntry
from .facet_info import FacetInfo
from .facet_key_attribute import FacetKeyAttribute
from .facet_request import FacetRequest
from .facet_result import FacetResult
from .facet_result_item import FacetResultItem
from .facet_statistics import FacetStatistics
from .facet_term import FacetTerm
from .failed_object import FailedObject
from .favorite_template_request_data import FavoriteTemplateRequestData
from .fax_document import FaxDocument
from .fax_document_entity_listing import FaxDocumentEntityListing
from .fax_send_request import FaxSendRequest
from .fax_send_response import FaxSendResponse
from .fax_summary import FaxSummary
from .filter_item import FilterItem
from .flow import Flow
from .flow_body import FlowBody
from .flow_body_format import FlowBodyFormat
from .flow_config_id import FlowConfigId
from .flow_config_meta_data import FlowConfigMetaData
from .flow_config_meta_data_entity_listing import FlowConfigMetaDataEntityListing
from .flow_details import FlowDetails
from .flow_details_search_result import FlowDetailsSearchResult
from .flow_entity_listing import FlowEntityListing
from .flow_exec_id import FlowExecId
from .flow_history_data_item import FlowHistoryDataItem
from .flow_history_item import FlowHistoryItem
from .flow_history_result_item import FlowHistoryResultItem
from .flow_history_result_item_entity_listing import FlowHistoryResultItemEntityListing
from .flow_input_data import FlowInputData
from .flow_launch_request import FlowLaunchRequest
from .flow_publish import FlowPublish
from .flow_report_result_item import FlowReportResultItem
from .flow_search_request import FlowSearchRequest
from .flow_state import FlowState
from .flow_terminate_request import FlowTerminateRequest
from .flow_upload_response import FlowUploadResponse
from .flow_version import FlowVersion
from .flow_version_config_meta_data import FlowVersionConfigMetaData
from .flow_version_config_meta_data_entity_listing import FlowVersionConfigMetaDataEntityListing
from .flow_version_entity_listing import FlowVersionEntityListing
from .form import Form
from .gateway import Gateway
from .geolocation import Geolocation
from .geolocation_settings import GeolocationSettings
from .gistener import Gistener
from .greeting import Greeting
from .greeting_audio_file import GreetingAudioFile
from .greeting_media_info import GreetingMediaInfo
from .greeting_owner import GreetingOwner
from .group import Group
from .group_entity_listing import GroupEntityListing
from .group_members_update import GroupMembersUpdate
from .group_tag import GroupTag
from .groups_search_response import GroupsSearchResponse
from .hipaa_config import HIPAAConfig
from .hardware_rate import HardwareRate
from .hardware_rate_listing import HardwareRateListing
from .health_check_info import HealthCheckInfo
from .ivr import IVR
from .ivr_entity_listing import IVREntityListing
from .import_status import ImportStatus
from .inbound_domain import InboundDomain
from .inbound_domain_entity_listing import InboundDomainEntityListing
from .inbound_route import InboundRoute
from .inbound_route_entity_listing import InboundRouteEntityListing
from .indexed_transform import IndexedTransform
from .integration_type import IntegrationType
from .integration_type_entity_listing import IntegrationTypeEntityListing
from .interaction_stats_alert import InteractionStatsAlert
from .interaction_stats_alert_container import InteractionStatsAlertContainer
from .interaction_stats_rule import InteractionStatsRule
from .interaction_stats_rule_container import InteractionStatsRuleContainer
from .invoice import Invoice
from .json_node import JsonNode
from .json_node_search_response import JsonNodeSearchResponse
from .key_rotation_schedule import KeyRotationSchedule
from .language import Language
from .language_entity_listing import LanguageEntityListing
from .library import Library
from .library_entity_listing import LibraryEntityListing
from .license import License
from .licenses_by_permission import LicensesByPermission
from .line import Line
from .line_base import LineBase
from .line_base_entity_listing import LineBaseEntityListing
from .line_entity_listing import LineEntityListing
from .line_status import LineStatus
from .linked_entity_listing_flow_details import LinkedEntityListingFlowDetails
from .linked_entity_listing_work_item_search_details import LinkedEntityListingWorkItemSearchDetails
from .lock_info import LockInfo
from .logical_interface_entity_listing import LogicalInterfaceEntityListing
from .management_unit import ManagementUnit
from .management_unit_timezone import ManagementUnitTimezone
from .max_participants import MaxParticipants
from .media_participant_request import MediaParticipantRequest
from .media_policies import MediaPolicies
from .media_result import MediaResult
from .media_setting import MediaSetting
from .media_summary import MediaSummary
from .media_summary_detail import MediaSummaryDetail
from .member_entity import MemberEntity
from .metabase import Metabase
from .metered_evaluation_assignment import MeteredEvaluationAssignment
from .noc_support import NocSupport
from .note import Note
from .note_listing import NoteListing
from .number import Number
from .number_order_request import NumberOrderRequest
from .number_plan import NumberPlan
from .numeric_range import NumericRange
from .o_auth_client import OAuthClient
from .o_auth_client_entity_listing import OAuthClientEntityListing
from .o_auth_provider import OAuthProvider
from .o_auth_provider_entity_listing import OAuthProviderEntityListing
from .observation_data_container import ObservationDataContainer
from .observation_query import ObservationQuery
from .observation_query_response import ObservationQueryResponse
from .okta import Okta
from .one_login import OneLogin
from .order import Order
from .org_license_assignment import OrgLicenseAssignment
from .org_media_utilization import OrgMediaUtilization
from .organization import Organization
from .organization_create import OrganizationCreate
from .organization_presence import OrganizationPresence
from .organization_presence_entity_listing import OrganizationPresenceEntityListing
from .organization_product_entity_listing import OrganizationProductEntityListing
from .organization_role_entity_listing import OrganizationRoleEntityListing
from .orphan_recording import OrphanRecording
from .orphan_recording_listing import OrphanRecordingListing
from .out_of_office import OutOfOffice
from .outbound_route import OutboundRoute
from .outbound_route_entity_listing import OutboundRouteEntityListing
from .pin_configuration import PINConfiguration
from .page import Page
from .paging_spec import PagingSpec
from .parameter import Parameter
from .parsed_certificate import ParsedCertificate
from .participant import Participant
from .participant_attributes import ParticipantAttributes
from .payment_method import PaymentMethod
from .payment_method_listing import PaymentMethodListing
from .payment_token_provider import PaymentTokenProvider
from .permission_collection_entity_listing import PermissionCollectionEntityListing
from .permissions import Permissions
from .phone import Phone
from .phone_base import PhoneBase
from .phone_base_entity_listing import PhoneBaseEntityListing
from .phone_capabilities import PhoneCapabilities
from .phone_column import PhoneColumn
from .phone_entity_listing import PhoneEntityListing
from .phone_meta_base_entity_listing import PhoneMetaBaseEntityListing
from .phone_number import PhoneNumber
from .phone_number_column import PhoneNumberColumn
from .phone_number_status import PhoneNumberStatus
from .phone_status import PhoneStatus
from .phones_reboot import PhonesReboot
from .physical_interface_entity_listing import PhysicalInterfaceEntityListing
from .policy import Policy
from .policy_actions import PolicyActions
from .policy_conditions import PolicyConditions
from .policy_entity_listing import PolicyEntityListing
from .policy_error_message import PolicyErrorMessage
from .policy_errors import PolicyErrors
from .prediction_results import PredictionResults
from .presence_query_response import PresenceQueryResponse
from .product import Product
from .prompt import Prompt
from .prompt_asset import PromptAsset
from .prompt_asset_entity_listing import PromptAssetEntityListing
from .prompt_entity_listing import PromptEntityListing
from .property_index_request import PropertyIndexRequest
from .provision_info import ProvisionInfo
from .publication import Publication
from .publish_script_request_data import PublishScriptRequestData
from .published_result import PublishedResult
from .pure_cloud import PureCloud
from .quality_audit import QualityAudit
from .quality_audit_page import QualityAuditPage
from .query_facet_info import QueryFacetInfo
from .query_request import QueryRequest
from .query_result import QueryResult
from .query_results import QueryResults
from .question_group import QuestionGroup
from .question_group_score import QuestionGroupScore
from .question_score import QuestionScore
from .queue import Queue
from .queue_entity_listing import QueueEntityListing
from .queue_member import QueueMember
from .queue_utilization_diagnostic import QueueUtilizationDiagnostic
from .quote import Quote
from .quote_charge import QuoteCharge
from .quote_listing import QuoteListing
from .rate import Rate
from .reaction import Reaction
from .recording import Recording
from .recording_email_message import RecordingEmailMessage
from .recording_settings import RecordingSettings
from .relationship import Relationship
from .relationship_listing import RelationshipListing
from .replace_request import ReplaceRequest
from .replace_response import ReplaceResponse
from .report_meta_data import ReportMetaData
from .report_meta_data_entity_listing import ReportMetaDataEntityListing
from .report_request import ReportRequest
from .report_run_entry import ReportRunEntry
from .report_run_entry_entity_domain_listing import ReportRunEntryEntityDomainListing
from .report_schedule import ReportSchedule
from .report_schedule_entity_listing import ReportScheduleEntityListing
from .reservation import Reservation
from .resource_condition_node import ResourceConditionNode
from .resource_condition_value import ResourceConditionValue
from .resource_permission_policy import ResourcePermissionPolicy
from .response import Response
from .response_entity_list import ResponseEntityList
from .response_entity_listing import ResponseEntityListing
from .response_filter import ResponseFilter
from .response_query_request import ResponseQueryRequest
from .response_query_results import ResponseQueryResults
from .response_set import ResponseSet
from .response_set_entity_listing import ResponseSetEntityListing
from .response_text import ResponseText
from .rest_error_detail import RestErrorDetail
from .retention_duration import RetentionDuration
from .ring import Ring
from .routing_skill import RoutingSkill
from .routing_status import RoutingStatus
from .rule_set import RuleSet
from .rule_set_entity_listing import RuleSetEntityListing
from .run_now_response import RunNowResponse
from .salesforce import Salesforce
from .schedule import Schedule
from .schedule_entity_listing import ScheduleEntityListing
from .schedule_group import ScheduleGroup
from .schedule_group_entity_listing import ScheduleGroupEntityListing
from .schema_category import SchemaCategory
from .schema_category_entity_listing import SchemaCategoryEntityListing
from .schema_reference_entity_listing import SchemaReferenceEntityListing
from .script import Script
from .script_entity_listing import ScriptEntityListing
from .search_aggregation import SearchAggregation
from .search_criteria import SearchCriteria
from .search_request import SearchRequest
from .security_profile import SecurityProfile
from .security_profile_entity_listing import SecurityProfileEntityListing
from .segment import Segment
from .sequence_schedule import SequenceSchedule
from .server_date import ServerDate
from .service import Service
from .service_context import ServiceContext
from .service_entity_listing import ServiceEntityListing
from .service_level import ServiceLevel
from .service_type import ServiceType
from .share import Share
from .share_entity_listing import ShareEntityListing
from .shared_entity import SharedEntity
from .shared_response import SharedResponse
from .sheet_schema import SheetSchema
from .sheet_transform import SheetTransform
from .signature_document_info import SignatureDocumentInfo
from .site import Site
from .site_entity_listing import SiteEntityListing
from .skill_entity_listing import SkillEntityListing
from .skills_to_remove import SkillsToRemove
from .snapshot import Snapshot
from .social_account import SocialAccount
from .social_conversation import SocialConversation
from .social_conversation_entity_listing import SocialConversationEntityListing
from .social_expression import SocialExpression
from .social_media_participant import SocialMediaParticipant
from .socialize_entity_filter import SocializeEntityFilter
from .socialize_filter_request import SocializeFilterRequest
from .sort_field import SortField
from .sort_item import SortItem
from .spreadsheet_transform import SpreadsheetTransform
from .spreadsheet_transform_entity_listing import SpreadsheetTransformEntityListing
from .station import Station
from .station_entity_listing import StationEntityListing
from .statistical_response import StatisticalResponse
from .statistical_summary import StatisticalSummary
from .sub_data_item import SubDataItem
from .subscriber_response import SubscriberResponse
from .support import Support
from .system_prompt import SystemPrompt
from .system_prompt_asset import SystemPromptAsset
from .system_prompt_asset_entity_listing import SystemPromptAssetEntityListing
from .system_prompt_entity_listing import SystemPromptEntityListing
from .table_transform import TableTransform
from .tag_model import TagModel
from .tag_query_request import TagQueryRequest
from .tag_value import TagValue
from .tag_value_entity_listing import TagValueEntityListing
from .template_entity_listing import TemplateEntityListing
from .term_attribute import TermAttribute
from .text_table_transform import TextTableTransform
from .text_table_transform_entity_listing import TextTableTransformEntityListing
from .third_party_account import ThirdPartyAccount
from .third_party_subscription import ThirdPartySubscription
from .ticker import Ticker
from .tier import Tier
from .time_allowed import TimeAllowed
from .time_interval import TimeInterval
from .time_slot import TimeSlot
from .time_zone import TimeZone
from .time_zone_entity_listing import TimeZoneEntityListing
from .trace import Trace
from .trace_list import TraceList
from .transfer_request import TransferRequest
from .transform_endpoint import TransformEndpoint
from .transform_lens import TransformLens
from .trunk import Trunk
from .trunk_base import TrunkBase
from .trunk_base_assignment import TrunkBaseAssignment
from .trunk_entity_listing import TrunkEntityListing
from .trunk_metabase_entity_listing import TrunkMetabaseEntityListing
from .twitter_expression import TwitterExpression
from .twitter_expression_buffer import TwitterExpressionBuffer
from .unpivot_columns import UnpivotColumns
from .unread_metric import UnreadMetric
from .unread_status import UnreadStatus
from .upload_progress import UploadProgress
from .uri_reference import UriReference
from .url_response import UrlResponse
from .user import User
from .user_action_category import UserActionCategory
from .user_action_category_entity_listing import UserActionCategoryEntityListing
from .user_action_metadata import UserActionMetadata
from .user_action_metadata_entity_listing import UserActionMetadataEntityListing
from .user_action_metadata_request import UserActionMetadataRequest
from .user_authorization import UserAuthorization
from .user_conversation_summary import UserConversationSummary
from .user_entity_listing import UserEntityListing
from .user_image import UserImage
from .user_license_assignment import UserLicenseAssignment
from .user_me import UserMe
from .user_param import UserParam
from .user_presence import UserPresence
from .user_queue import UserQueue
from .user_queue_entity_listing import UserQueueEntityListing
from .user_recording import UserRecording
from .user_recording_entity_listing import UserRecordingEntityListing
from .user_routing_skill import UserRoutingSkill
from .user_skill_entity_listing import UserSkillEntityListing
from .user_station import UserStation
from .user_stations import UserStations
from .users_entity_listing import UsersEntityListing
from .users_search_response import UsersSearchResponse
from .utilization import Utilization
from .validate_address_request import ValidateAddressRequest
from .validate_address_response import ValidateAddressResponse
from .value import Value
from .vendor_connection_request import VendorConnectionRequest
from .video import Video
from .video_conversation import VideoConversation
from .video_conversation_entity_listing import VideoConversationEntityListing
from .video_media_participant import VideoMediaParticipant
from .view import View
from .voice_rate import VoiceRate
from .voice_rate_extended import VoiceRateExtended
from .voice_rate_international import VoiceRateInternational
from .voice_rate_international_entity_listing import VoiceRateInternationalEntityListing
from .voice_rate_update import VoiceRateUpdate
from .voice_rates_csv import VoiceRatesCsv
from .voice_xml_operation import VoiceXmlOperation
from .voice_xml_operation_entity_listing import VoiceXmlOperationEntityListing
from .voicemail_mailbox_info import VoicemailMailboxInfo
from .voicemail_media_info import VoicemailMediaInfo
from .voicemail_message import VoicemailMessage
from .voicemail_message_entity_listing import VoicemailMessageEntityListing
from .voicemail_organization_policy import VoicemailOrganizationPolicy
from .voicemail_user_policy import VoicemailUserPolicy
from .vpn import Vpn
from .work_item import WorkItem
from .work_item_actions import WorkItemActions
from .work_item_cache import WorkItemCache
from .work_item_command import WorkItemCommand
from .work_item_command_group import WorkItemCommandGroup
from .work_item_definition import WorkItemDefinition
from .work_item_details import WorkItemDetails
from .work_item_search_details import WorkItemSearchDetails
from .work_item_search_details_search_result import WorkItemSearchDetailsSearchResult
from .work_item_submit_request import WorkItemSubmitRequest
from .work_item_transfer_request import WorkItemTransferRequest
from .workspace import Workspace
from .workspace_create import WorkspaceCreate
from .workspace_entity_listing import WorkspaceEntityListing
from .workspace_member import WorkspaceMember
from .workspace_member_entity_listing import WorkspaceMemberEntityListing
from .workspace_summary import WorkspaceSummary
from .wrap_up_code_mapping import WrapUpCodeMapping
from .wrapup import Wrapup
from .wrapup_code import WrapupCode
from .wrapup_code_entity_listing import WrapupCodeEntityListing
from .xlsx_schema import XlsxSchema



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class AvailableAdditionalService(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AvailableAdditionalService - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'part_number': 'str',
            'required_for_products': 'list[str]',
            'available_for_products': 'list[str]',
            'default_for_products': 'list[str]',
            'exclusive_from_products': 'list[str]',
            'rate': 'Rate',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'part_number': 'partNumber',
            'required_for_products': 'requiredForProducts',
            'available_for_products': 'availableForProducts',
            'default_for_products': 'defaultForProducts',
            'exclusive_from_products': 'exclusiveFromProducts',
            'rate': 'rate',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._part_number = None
        self._required_for_products = None
        self._available_for_products = None
        self._default_for_products = None
        self._exclusive_from_products = None
        self._rate = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this AvailableAdditionalService.
        The globally unique identifier for the object.

        :return: The id of this AvailableAdditionalService.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AvailableAdditionalService.
        The globally unique identifier for the object.

        :param id: The id of this AvailableAdditionalService.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this AvailableAdditionalService.


        :return: The name of this AvailableAdditionalService.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AvailableAdditionalService.


        :param name: The name of this AvailableAdditionalService.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this AvailableAdditionalService.
        The description of this additional service.

        :return: The description of this AvailableAdditionalService.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AvailableAdditionalService.
        The description of this additional service.

        :param description: The description of this AvailableAdditionalService.
        :type: str
        """
        self._description = description

    @property
    def part_number(self):
        """
        Gets the part_number of this AvailableAdditionalService.
        The part number of this additional service.

        :return: The part_number of this AvailableAdditionalService.
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """
        Sets the part_number of this AvailableAdditionalService.
        The part number of this additional service.

        :param part_number: The part_number of this AvailableAdditionalService.
        :type: str
        """
        self._part_number = part_number

    @property
    def required_for_products(self):
        """
        Gets the required_for_products of this AvailableAdditionalService.
        The list of products which require this additional service.

        :return: The required_for_products of this AvailableAdditionalService.
        :rtype: list[str]
        """
        return self._required_for_products

    @required_for_products.setter
    def required_for_products(self, required_for_products):
        """
        Sets the required_for_products of this AvailableAdditionalService.
        The list of products which require this additional service.

        :param required_for_products: The required_for_products of this AvailableAdditionalService.
        :type: list[str]
        """
        self._required_for_products = required_for_products

    @property
    def available_for_products(self):
        """
        Gets the available_for_products of this AvailableAdditionalService.
        The list of products for which this additional service is available.

        :return: The available_for_products of this AvailableAdditionalService.
        :rtype: list[str]
        """
        return self._available_for_products

    @available_for_products.setter
    def available_for_products(self, available_for_products):
        """
        Sets the available_for_products of this AvailableAdditionalService.
        The list of products for which this additional service is available.

        :param available_for_products: The available_for_products of this AvailableAdditionalService.
        :type: list[str]
        """
        self._available_for_products = available_for_products

    @property
    def default_for_products(self):
        """
        Gets the default_for_products of this AvailableAdditionalService.
        The list of products which have this additional service by default.

        :return: The default_for_products of this AvailableAdditionalService.
        :rtype: list[str]
        """
        return self._default_for_products

    @default_for_products.setter
    def default_for_products(self, default_for_products):
        """
        Sets the default_for_products of this AvailableAdditionalService.
        The list of products which have this additional service by default.

        :param default_for_products: The default_for_products of this AvailableAdditionalService.
        :type: list[str]
        """
        self._default_for_products = default_for_products

    @property
    def exclusive_from_products(self):
        """
        Gets the exclusive_from_products of this AvailableAdditionalService.
        The list of additional services which are not compatible with this additional service.

        :return: The exclusive_from_products of this AvailableAdditionalService.
        :rtype: list[str]
        """
        return self._exclusive_from_products

    @exclusive_from_products.setter
    def exclusive_from_products(self, exclusive_from_products):
        """
        Sets the exclusive_from_products of this AvailableAdditionalService.
        The list of additional services which are not compatible with this additional service.

        :param exclusive_from_products: The exclusive_from_products of this AvailableAdditionalService.
        :type: list[str]
        """
        self._exclusive_from_products = exclusive_from_products

    @property
    def rate(self):
        """
        Gets the rate of this AvailableAdditionalService.
        The rate of this additional service.

        :return: The rate of this AvailableAdditionalService.
        :rtype: Rate
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """
        Sets the rate of this AvailableAdditionalService.
        The rate of this additional service.

        :param rate: The rate of this AvailableAdditionalService.
        :type: Rate
        """
        self._rate = rate

    @property
    def self_uri(self):
        """
        Gets the self_uri of this AvailableAdditionalService.
        The URI for this object

        :return: The self_uri of this AvailableAdditionalService.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this AvailableAdditionalService.
        The URI for this object

        :param self_uri: The self_uri of this AvailableAdditionalService.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class EmailMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EmailMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'to': 'list[EmailAddress]',
            'cc': 'list[EmailAddress]',
            'bcc': 'list[EmailAddress]',
            'pcFrom': 'EmailAddress',
            'subject': 'str',
            'attachments': 'list[Attachment]',
            'text_body': 'str',
            'html_body': 'str',
            'time': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'to': 'to',
            'cc': 'cc',
            'bcc': 'bcc',
            'pcFrom': 'from',
            'subject': 'subject',
            'attachments': 'attachments',
            'text_body': 'textBody',
            'html_body': 'htmlBody',
            'time': 'time',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._to = None
        self._cc = None
        self._bcc = None
        self._pcFrom = None
        self._subject = None
        self._attachments = None
        self._text_body = None
        self._html_body = None
        self._time = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EmailMessage.
        The globally unique identifier for the object.

        :return: The id of this EmailMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EmailMessage.
        The globally unique identifier for the object.

        :param id: The id of this EmailMessage.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EmailMessage.


        :return: The name of this EmailMessage.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EmailMessage.


        :param name: The name of this EmailMessage.
        :type: str
        """
        self._name = name

    @property
    def to(self):
        """
        Gets the to of this EmailMessage.
        The recipients of the email message.

        :return: The to of this EmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._to

    @to.setter
    def to(self, to):
        """
        Sets the to of this EmailMessage.
        The recipients of the email message.

        :param to: The to of this EmailMessage.
        :type: list[EmailAddress]
        """
        self._to = to

    @property
    def cc(self):
        """
        Gets the cc of this EmailMessage.
        The recipients that were copied on the email message.

        :return: The cc of this EmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """
        Sets the cc of this EmailMessage.
        The recipients that were copied on the email message.

        :param cc: The cc of this EmailMessage.
        :type: list[EmailAddress]
        """
        self._cc = cc

    @property
    def bcc(self):
        """
        Gets the bcc of this EmailMessage.
        The recipients that were blind copied on the email message.

        :return: The bcc of this EmailMessage.
        :rtype: list[EmailAddress]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """
        Sets the bcc of this EmailMessage.
        The recipients that were blind copied on the email message.

        :param bcc: The bcc of this EmailMessage.
        :type: list[EmailAddress]
        """
        self._bcc = bcc

    @property
    def pcFrom(self):
        """
        Gets the pcFrom of this EmailMessage.
        The sender of the email message.

        :return: The pcFrom of this EmailMessage.
        :rtype: EmailAddress
        """
        return self._pcFrom

    @pcFrom.setter
    def pcFrom(self, pcFrom):
        """
        Sets the pcFrom of this EmailMessage.
        The sender of the email message.

        :param pcFrom: The pcFrom of this EmailMessage.
        :type: EmailAddress
        """
        self._pcFrom = pcFrom

    @property
    def subject(self):
        """
        Gets the subject of this EmailMessage.
        The subject of the email message.

        :return: The subject of this EmailMessage.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this EmailMessage.
        The subject of the email message.

        :param subject: The subject of this EmailMessage.
        :type: str
        """
        self._subject = subject

    @property
    def attachments(self):
        """
        Gets the attachments of this EmailMessage.
        The attachments of the email message.

        :return: The attachments of this EmailMessage.
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """
        Sets the attachments of this EmailMessage.
        The attachments of the email message.

        :param attachments: The attachments of this EmailMessage.
        :type: list[Attachment]
        """
        self._attachments = attachments

    @property
    def text_body(self):
        """
        Gets the text_body of this EmailMessage.
        The text body of the email message.

        :return: The text_body of this EmailMessage.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this EmailMessage.
        The text body of the email message.

        :param text_body: The text_body of this EmailMessage.
        :type: str
        """
        self._text_body = text_body

    @property
    def html_body(self):
        """
        Gets the html_body of this EmailMessage.
        The html body of the email message.

        :return: The html_body of this EmailMessage.
        :rtype: str
        """
        return self._html_body

    @html_body.setter
    def html_body(self, html_body):
        """
        Sets the html_body of this EmailMessage.
        The html body of the email message.

        :param html_body: The html_body of this EmailMessage.
        :type: str
        """
        self._html_body = html_body

    @property
    def time(self):
        """
        Gets the time of this EmailMessage.
        The time when the message was received or sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The time of this EmailMessage.
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this EmailMessage.
        The time when the message was received or sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param time: The time of this EmailMessage.
        :type: datetime
        """
        self._time = time

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EmailMessage.
        The URI for this object

        :return: The self_uri of this EmailMessage.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EmailMessage.
        The URI for this object

        :param self_uri: The self_uri of this EmailMessage.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoicemailUserPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailUserPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'enabled': 'bool',
            'alert_timeout_seconds': 'int',
            'minimum_recording_time_seconds': 'int',
            'maximum_recording_time_seconds': 'int',
            'unavailable_message_uri': 'str',
            'name_prompt_message_uri': 'str',
            'full_message_uri': 'str',
            'pin': 'str',
            'quota_size_bytes': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime'
        }

        self.attribute_map = {
            'enabled': 'enabled',
            'alert_timeout_seconds': 'alertTimeoutSeconds',
            'minimum_recording_time_seconds': 'minimumRecordingTimeSeconds',
            'maximum_recording_time_seconds': 'maximumRecordingTimeSeconds',
            'unavailable_message_uri': 'unavailableMessageUri',
            'name_prompt_message_uri': 'namePromptMessageUri',
            'full_message_uri': 'fullMessageUri',
            'pin': 'pin',
            'quota_size_bytes': 'quotaSizeBytes',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate'
        }

        self._enabled = False
        self._alert_timeout_seconds = None
        self._minimum_recording_time_seconds = None
        self._maximum_recording_time_seconds = None
        self._unavailable_message_uri = None
        self._name_prompt_message_uri = None
        self._full_message_uri = None
        self._pin = None
        self._quota_size_bytes = None
        self._created_date = None
        self._modified_date = None

    @property
    def enabled(self):
        """
        Gets the enabled of this VoicemailUserPolicy.


        :return: The enabled of this VoicemailUserPolicy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this VoicemailUserPolicy.


        :param enabled: The enabled of this VoicemailUserPolicy.
        :type: bool
        """
        self._enabled = enabled

    @property
    def alert_timeout_seconds(self):
        """
        Gets the alert_timeout_seconds of this VoicemailUserPolicy.


        :return: The alert_timeout_seconds of this VoicemailUserPolicy.
        :rtype: int
        """
        return self._alert_timeout_seconds

    @alert_timeout_seconds.setter
    def alert_timeout_seconds(self, alert_timeout_seconds):
        """
        Sets the alert_timeout_seconds of this VoicemailUserPolicy.


        :param alert_timeout_seconds: The alert_timeout_seconds of this VoicemailUserPolicy.
        :type: int
        """
        self._alert_timeout_seconds = alert_timeout_seconds

    @property
    def minimum_recording_time_seconds(self):
        """
        Gets the minimum_recording_time_seconds of this VoicemailUserPolicy.


        :return: The minimum_recording_time_seconds of this VoicemailUserPolicy.
        :rtype: int
        """
        return self._minimum_recording_time_seconds

    @minimum_recording_time_seconds.setter
    def minimum_recording_time_seconds(self, minimum_recording_time_seconds):
        """
        Sets the minimum_recording_time_seconds of this VoicemailUserPolicy.


        :param minimum_recording_time_seconds: The minimum_recording_time_seconds of this VoicemailUserPolicy.
        :type: int
        """
        self._minimum_recording_time_seconds = minimum_recording_time_seconds

    @property
    def maximum_recording_time_seconds(self):
        """
        Gets the maximum_recording_time_seconds of this VoicemailUserPolicy.


        :return: The maximum_recording_time_seconds of this VoicemailUserPolicy.
        :rtype: int
        """
        return self._maximum_recording_time_seconds

    @maximum_recording_time_seconds.setter
    def maximum_recording_time_seconds(self, maximum_recording_time_seconds):
        """
        Sets the maximum_recording_time_seconds of this VoicemailUserPolicy.


        :param maximum_recording_time_seconds: The maximum_recording_time_seconds of this VoicemailUserPolicy.
        :type: int
        """
        self._maximum_recording_time_seconds = maximum_recording_time_seconds

    @property
    def unavailable_message_uri(self):
        """
        Gets the unavailable_message_uri of this VoicemailUserPolicy.


        :return: The unavailable_message_uri of this VoicemailUserPolicy.
        :rtype: str
        """
        return self._unavailable_message_uri

    @unavailable_message_uri.setter
    def unavailable_message_uri(self, unavailable_message_uri):
        """
        Sets the unavailable_message_uri of this VoicemailUserPolicy.


        :param unavailable_message_uri: The unavailable_message_uri of this VoicemailUserPolicy.
        :type: str
        """
        self._unavailable_message_uri = unavailable_message_uri

    @property
    def name_prompt_message_uri(self):
        """
        Gets the name_prompt_message_uri of this VoicemailUserPolicy.


        :return: The name_prompt_message_uri of this VoicemailUserPolicy.
        :rtype: str
        """
        return self._name_prompt_message_uri

    @name_prompt_message_uri.setter
    def name_prompt_message_uri(self, name_prompt_message_uri):
        """
        Sets the name_prompt_message_uri of this VoicemailUserPolicy.


        :param name_prompt_message_uri: The name_prompt_message_uri of this VoicemailUserPolicy.
        :type: str
        """
        self._name_prompt_message_uri = name_prompt_message_uri

    @property
    def full_message_uri(self):
        """
        Gets the full_message_uri of this VoicemailUserPolicy.


        :return: The full_message_uri of this VoicemailUserPolicy.
        :rtype: str
        """
        return self._full_message_uri

    @full_message_uri.setter
    def full_message_uri(self, full_message_uri):
        """
        Sets the full_message_uri of this VoicemailUserPolicy.


        :param full_message_uri: The full_message_uri of this VoicemailUserPolicy.
        :type: str
        """
        self._full_message_uri = full_message_uri

    @property
    def pin(self):
        """
        Gets the pin of this VoicemailUserPolicy.


        :return: The pin of this VoicemailUserPolicy.
        :rtype: str
        """
        return self._pin

    @pin.setter
    def pin(self, pin):
        """
        Sets the pin of this VoicemailUserPolicy.


        :param pin: The pin of this VoicemailUserPolicy.
        :type: str
        """
        self._pin = pin

    @property
    def quota_size_bytes(self):
        """
        Gets the quota_size_bytes of this VoicemailUserPolicy.


        :return: The quota_size_bytes of this VoicemailUserPolicy.
        :rtype: int
        """
        return self._quota_size_bytes

    @quota_size_bytes.setter
    def quota_size_bytes(self, quota_size_bytes):
        """
        Sets the quota_size_bytes of this VoicemailUserPolicy.


        :param quota_size_bytes: The quota_size_bytes of this VoicemailUserPolicy.
        :type: int
        """
        self._quota_size_bytes = quota_size_bytes

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailUserPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this VoicemailUserPolicy.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailUserPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this VoicemailUserPolicy.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailUserPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this VoicemailUserPolicy.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailUserPolicy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this VoicemailUserPolicy.
        :type: datetime
        """
        self._modified_date = modified_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SearchCriteria(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SearchCriteria - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'end_value': 'str',
            'values': 'list[str]',
            'start_value': 'str',
            'type': 'str',
            'fields': 'list[str]',
            'value': 'str',
            'operator': 'str',
            'group': 'list[SearchCriteria]'
        }

        self.attribute_map = {
            'end_value': 'endValue',
            'values': 'values',
            'start_value': 'startValue',
            'type': 'type',
            'fields': 'fields',
            'value': 'value',
            'operator': 'operator',
            'group': 'group'
        }

        self._end_value = None
        self._values = None
        self._start_value = None
        self._type = None
        self._fields = None
        self._value = None
        self._operator = None
        self._group = None

    @property
    def end_value(self):
        """
        Gets the end_value of this SearchCriteria.


        :return: The end_value of this SearchCriteria.
        :rtype: str
        """
        return self._end_value

    @end_value.setter
    def end_value(self, end_value):
        """
        Sets the end_value of this SearchCriteria.


        :param end_value: The end_value of this SearchCriteria.
        :type: str
        """
        self._end_value = end_value

    @property
    def values(self):
        """
        Gets the values of this SearchCriteria.


        :return: The values of this SearchCriteria.
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this SearchCriteria.


        :param values: The values of this SearchCriteria.
        :type: list[str]
        """
        self._values = values

    @property
    def start_value(self):
        """
        Gets the start_value of this SearchCriteria.


        :return: The start_value of this SearchCriteria.
        :rtype: str
        """
        return self._start_value

    @start_value.setter
    def start_value(self, start_value):
        """
        Sets the start_value of this SearchCriteria.


        :param start_value: The start_value of this SearchCriteria.
        :type: str
        """
        self._start_value = start_value

    @property
    def type(self):
        """
        Gets the type of this SearchCriteria.


        :return: The type of this SearchCriteria.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SearchCriteria.


        :param type: The type of this SearchCriteria.
        :type: str
        """
        allowed_values = ["EXACT", "CONTAINS", "STARTS_WITH", "REQUIRED_FIELDS", "RANGE", "DATE_RANGE", "LESS_THAN", "LESS_THAN_EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL_TO", "SIMPLE_STRING"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def fields(self):
        """
        Gets the fields of this SearchCriteria.


        :return: The fields of this SearchCriteria.
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this SearchCriteria.


        :param fields: The fields of this SearchCriteria.
        :type: list[str]
        """
        self._fields = fields

    @property
    def value(self):
        """
        Gets the value of this SearchCriteria.


        :return: The value of this SearchCriteria.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SearchCriteria.


        :param value: The value of this SearchCriteria.
        :type: str
        """
        self._value = value

    @property
    def operator(self):
        """
        Gets the operator of this SearchCriteria.


        :return: The operator of this SearchCriteria.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this SearchCriteria.


        :param operator: The operator of this SearchCriteria.
        :type: str
        """
        allowed_values = ["AND", "OR", "NOT"]
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator`, must be one of {0}"
                .format(allowed_values)
            )
        self._operator = operator

    @property
    def group(self):
        """
        Gets the group of this SearchCriteria.


        :return: The group of this SearchCriteria.
        :rtype: list[SearchCriteria]
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this SearchCriteria.


        :param group: The group of this SearchCriteria.
        :type: list[SearchCriteria]
        """
        self._group = group

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class PhoneNumber(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PhoneNumber - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'display': 'str',
            'extension': 'int',
            'accepts_sms': 'bool',
            'user_input': 'str',
            'e164': 'str',
            'country_code': 'str'
        }

        self.attribute_map = {
            'display': 'display',
            'extension': 'extension',
            'accepts_sms': 'acceptsSMS',
            'user_input': 'userInput',
            'e164': 'e164',
            'country_code': 'countryCode'
        }

        self._display = None
        self._extension = None
        self._accepts_sms = False
        self._user_input = None
        self._e164 = None
        self._country_code = None

    @property
    def display(self):
        """
        Gets the display of this PhoneNumber.


        :return: The display of this PhoneNumber.
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """
        Sets the display of this PhoneNumber.


        :param display: The display of this PhoneNumber.
        :type: str
        """
        self._display = display

    @property
    def extension(self):
        """
        Gets the extension of this PhoneNumber.


        :return: The extension of this PhoneNumber.
        :rtype: int
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """
        Sets the extension of this PhoneNumber.


        :param extension: The extension of this PhoneNumber.
        :type: int
        """
        self._extension = extension

    @property
    def accepts_sms(self):
        """
        Gets the accepts_sms of this PhoneNumber.


        :return: The accepts_sms of this PhoneNumber.
        :rtype: bool
        """
        return self._accepts_sms

    @accepts_sms.setter
    def accepts_sms(self, accepts_sms):
        """
        Sets the accepts_sms of this PhoneNumber.


        :param accepts_sms: The accepts_sms of this PhoneNumber.
        :type: bool
        """
        self._accepts_sms = accepts_sms

    @property
    def user_input(self):
        """
        Gets the user_input of this PhoneNumber.


        :return: The user_input of this PhoneNumber.
        :rtype: str
        """
        return self._user_input

    @user_input.setter
    def user_input(self, user_input):
        """
        Sets the user_input of this PhoneNumber.


        :param user_input: The user_input of this PhoneNumber.
        :type: str
        """
        self._user_input = user_input

    @property
    def e164(self):
        """
        Gets the e164 of this PhoneNumber.


        :return: The e164 of this PhoneNumber.
        :rtype: str
        """
        return self._e164

    @e164.setter
    def e164(self, e164):
        """
        Sets the e164 of this PhoneNumber.


        :param e164: The e164 of this PhoneNumber.
        :type: str
        """
        self._e164 = e164

    @property
    def country_code(self):
        """
        Gets the country_code of this PhoneNumber.


        :return: The country_code of this PhoneNumber.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this PhoneNumber.


        :param country_code: The country_code of this PhoneNumber.
        :type: str
        """
        self._country_code = country_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

